# -*- coding: utf-8 -*-

"""Add concurrency to methods and functions in a single line of code."""

import lox.worker.thread
import lox.worker.process
